==> tiered_antibiotic_resistance_model-2.0.2.tar.gz: tiered_antibiotic_resistance_model-2.0.2/README.md <==
![Build status](https://github.com/Warwick-iGEM-2021/modelling/actions/workflows/python-app.yml/badge.svg)

# Warwick iGEM computational modelling

A repository containing code for custom computational modelling components
within the 2021 Warwick team iGEM project.

We used Python to implement a discrete time, stochastic, compartmental model of
the spread of antibiotic resistant pathogens through a population.

## Model abstract

We propose a validated computational model of the spread of an antibiotic
resistant pathogens in a hospital, with and without our diagnostic tool for
quickly identifying it, and show that in a relevant scenario it reduces the
presence of antibiotic resistant pathogens in our selected scenario, showing our
product is beneficial in the real-world.

## Writeup and production code

The writeup for the entire project can be found here:

- [As a markdown document](https://raw.githubusercontent.com/Warwick-iGEM-2021/modelling/main/writeup/writeup.md)
- [As a PDF file](https://raw.githubusercontent.com/Warwick-iGEM-2021/modelling/main/writeup/writeup.pdf)
- [As part of the Warwick iGEM 2021 wiki](https://2021.igem.org/Team:Warwick/Model)

The final production code for the project can be found here:

- [As a standalone python file](https://raw.githubusercontent.com/Warwick-iGEM-2021/modelling/main/tiered_antibiotic_resistance_model/model.py)
- [As a package on PyPI](https://pypi.org/project/tiered-antibiotic-resistance-model/2.0.1/)

## Team

The core team members of the project are:

- [Edmund Goodman](https://github.com/EdmundGoodman), Model design and software
  implementation
- [Axel Schoerner Emillon](https://www.linkedin.com/in/axel-schoerner-emillon/),
  Model design and data analysis

With thanks to [Reanna Gregory](https://www.linkedin.com/in/reanna-gregory-481309201/), [Alex Darlington](https://warwick.ac.uk/fac/sci/eng/people/alexander_darlington/), and the rest of the 2021 iGEM Warwick team for their time discussing the initial design and ways to improve the model.

## Contributions and errata

If you find a bug in the code or an error in the writeup, feel free to submit
a pull request or an issue through GitHub, and we will endeavour to fix it!

==> tiered_antibiotic_resistance_model-2.0.3.tar.gz: tiered_antibiotic_resistance_model-2.0.3/README.md <==
![Build status](https://github.com/Warwick-iGEM-2021/modelling/actions/workflows/python-app.yml/badge.svg)

# Warwick iGEM computational modelling

A repository containing code for custom computational modelling components
within the 2021 Warwick team iGEM project.

We used Python to implement a discrete time, stochastic, compartmental model of
the spread of antibiotic resistant pathogens through a population.

## Model abstract

We propose a validated computational model of the spread of an antibiotic
resistant pathogens in a hospital, with and without our diagnostic tool for
quickly identifying it, and show that in a relevant scenario it reduces the
presence of antibiotic resistant pathogens in our selected scenario, showing our
product is beneficial in the real-world.

## Writeup, documentation and production code

The writeup for the entire project can be found here:

- [As a markdown document](https://raw.githubusercontent.com/Warwick-iGEM-2021/modelling/main/writeup/writeup.md)
- [As a PDF file](https://raw.githubusercontent.com/Warwick-iGEM-2021/modelling/main/writeup/writeup.pdf)
- [As part of the Warwick iGEM 2021 wiki](https://2021.igem.org/Team:Warwick/Model)

The documentation for the production code can be found here:
- [On readthedocs.io](https://tiered-antibiotic-resistance-model.readthedocs.io/en/latest/)

The final production code for the project can be found here:

- [As a standalone python file](https://raw.githubusercontent.com/Warwick-iGEM-2021/modelling/main/tiered_antibiotic_resistance_model/model.py)
- [As a package on PyPI](https://pypi.org/project/tiered-antibiotic-resistance-model/2.0.1/)

## Team

The core team members of the project are:

- [Edmund Goodman](https://github.com/EdmundGoodman), Model design and software
  implementation
- [Axel Schoerner Emillon](https://www.linkedin.com/in/axel-schoerner-emillon/),
  Model design and data analysis

With thanks to [Reanna Gregory](https://www.linkedin.com/in/reanna-gregory-481309201/), [Alex Darlington](https://warwick.ac.uk/fac/sci/eng/people/alexander_darlington/), and the rest of the 2021 iGEM Warwick team for their time discussing the initial design and ways to improve the model.

## Contributions and errata

If you find a bug in the code or an error in the writeup, feel free to submit
a pull request or an issue through GitHub, and we will endeavour to fix it!
